git: db83952138a9 - stable/12 - release: permanently remove the 'reldoc' target and associates

Glen Barber gjb at FreeBSD.org
Wed May 12 15:51:01 UTC 2021


The branch stable/12 has been updated by gjb:

URL: https://cgit.FreeBSD.org/src/commit/?id=db83952138a9c65ba9ac77b2fb5801159fd1e915

commit db83952138a9c65ba9ac77b2fb5801159fd1e915
Author:     Glen Barber <gjb at FreeBSD.org>
AuthorDate: 2021-02-18 04:00:03 +0000
Commit:     Glen Barber <gjb at FreeBSD.org>
CommitDate: 2021-05-12 15:11:18 +0000

    release: permanently remove the 'reldoc' target and associates
    
    Following 7b1d1a1658ffb69eff93afc713f9e88ed8b20eac, the structure
    for the reldoc target has significantly changed as result of the
    ASCIIDoctor/Hugo migration.  As the release notes related files
    on the installation medium are inherently out of date, purge them
    entirely.
    
    Discussed within:       re, doceng
    No objection:           re (silence), doceng (silence)
    Timeout:                2 weeks
    Sponsored by:           Rubicon Communications, LLC ("Netgate")
    
    (cherry picked from commit f61e92ca5a23450bc28169bbdd71d7674df98c19)
---
 release/Makefile              | 41 -----------------------
 release/arm/GENERICSD.conf    |  6 +++-
 release/arm/RPI-B.conf        |  1 -
 release/arm64/PINE64-LTS.conf |  1 -
 release/arm64/PINE64.conf     |  1 -
 release/arm64/PINEBOOK.conf   |  1 -
 release/arm64/ROCKPRO64.conf  |  1 -
 release/release.conf.sample   | 17 ++++++----
 release/release.sh            | 77 +++++++++++++++++++++----------------------
 9 files changed, 52 insertions(+), 94 deletions(-)

diff --git a/release/Makefile b/release/Makefile
index db6a56296c6a..09b1b6a2c855 100644
--- a/release/Makefile
+++ b/release/Makefile
@@ -20,12 +20,10 @@
 #  WORLDDIR: location of src tree -- must have built world and default kernel
 #            (by default, the directory above this one)
 #  PORTSDIR: location of ports tree to distribute (default: /usr/ports)
-#  DOCDIR:   location of doc tree (default: /usr/doc)
 #  XTRADIR:  xtra-bits-dir argument for <arch>/mkisoimages.sh
 #  NOPKG:    if set, do not distribute third-party packages
 #  NOPORTS:  if set, do not distribute ports tree
 #  NOSRC:    if set, do not distribute source tree
-#  NODOC:    if set, do not generate release documentation
 #  WITH_DVD: if set, generate dvd1.iso
 #  WITH_COMPRESSED_IMAGES: if set, compress installation images with xz(1)
 #		(uncompressed images are not removed)
@@ -38,7 +36,6 @@
 
 WORLDDIR?=	${.CURDIR}/..
 PORTSDIR?=	/usr/ports
-DOCDIR?=	/usr/doc
 RELNOTES_LANG?= en_US.ISO8859-1
 
 .if !defined(TARGET) || empty(TARGET)
@@ -74,9 +71,6 @@ VOLUME_LABEL=	${REVISION:C/[.-]/_/g}_${BRANCH:C/[.-]/_/g}_${TARGET_ARCH}
 VOLUME_LABEL=	FreeBSD_Install
 .endif
 
-.if !exists(${DOCDIR})
-NODOC= true
-.endif
 .if !exists(${PORTSDIR})
 NOPORTS= true
 .endif
@@ -88,9 +82,6 @@ EXTRA_PACKAGES+= ports.txz
 .if !defined(NOSRC)
 EXTRA_PACKAGES+= src.txz
 .endif
-#.if !defined(NODOC)
-#EXTRA_PACKAGES+= reldoc
-#.endif
 
 RELEASE_TARGETS= ftp
 IMAGES=
@@ -119,9 +110,6 @@ CLEANFILES+=	${I}.xz
 CLEANFILES+=	pkg-stage
 .endif
 CLEANDIRS=	dist ftp disc1 bootonly dvd
-#.if !defined(NODOC)
-#CLEANDIRS+=    reldoc rdoc
-#.endif
 beforeclean:
 	chflags -R noschg .
 .include <bsd.obj.mk>
@@ -161,23 +149,6 @@ ports.txz:
 	    --exclude 'usr/ports/INDEX*' --exclude work usr/ports | \
 	    ${XZ_CMD} > ${.OBJDIR}/ports.txz
 
-#reldoc:
-#	cd ${DOCDIR}/en_US.ISO8859-1/htdocs/releases/${REVISION}R && \
-#	    env MAN4DIR=${WORLDDIR}/share/man/man4 \
-#	    _BRANCH=${BRANCH} \
-#	    ${MAKE} all install clean "FORMATS=html txt" \
-#	    INSTALL_COMPRESSED='' URLS_ABSOLUTE=YES DOCDIR=${.OBJDIR}/rdoc \
-#	    WEBDIR=${DOCDIR} DESTDIR=${.OBJDIR}/rdoc
-#	mkdir -p reldoc
-#.for i in hardware readme relnotes errata
-#	ln -f ${.OBJDIR}/rdoc/${i:tl}.txt \
-#		reldoc/${i:tu}.TXT
-#	ln -f ${.OBJDIR}/rdoc/${i:tl}.html \
-#		reldoc/${i:tu}.HTML
-#.endfor
-#	cp ${.OBJDIR}/rdoc/docbook.css \
-#		reldoc/
-
 disc1: packagesystem
 # Install system
 	mkdir -p ${.TARGET}
@@ -193,10 +164,6 @@ disc1: packagesystem
 	for dist in MANIFEST $$(ls *.txz | grep -vE -- '(base|lib32)-dbg'); \
 	    do cp $${dist} ${.TARGET}/usr/freebsd-dist; \
 	done
-# Copy documentation, if generated
-#.if !defined(NODOC)
-#	cp reldoc/* ${.TARGET}
-#.endif
 # Set up installation environment
 	ln -fs /tmp/bsdinstall_etc/resolv.conf ${.TARGET}/etc/resolv.conf
 	echo sendmail_enable=\"NONE\" > ${.TARGET}/etc/rc.conf
@@ -220,10 +187,6 @@ bootonly: packagesystem
 # Copy manifest only (no distfiles) to get checksums
 	mkdir -p ${.TARGET}/usr/freebsd-dist
 	cp MANIFEST ${.TARGET}/usr/freebsd-dist
-# Copy documentation, if generated
-#.if !defined(NODOC)
-#	cp reldoc/* ${.TARGET}
-#.endif
 # Set up installation environment
 	ln -fs /tmp/bsdinstall_etc/resolv.conf ${.TARGET}/etc/resolv.conf
 	echo sendmail_enable=\"NONE\" > ${.TARGET}/etc/rc.conf
@@ -244,10 +207,6 @@ dvd: packagesystem
 	for dist in MANIFEST $$(ls *.txz | grep -v -- '(base|lib32)-dbg'); \
 	    do cp $${dist} ${.TARGET}/usr/freebsd-dist; \
 	done
-# Copy documentation, if generated
-#.if !defined(NODOC)
-#	cp reldoc/* ${.TARGET}
-#.endif
 # Set up installation environment
 	ln -fs /tmp/bsdinstall_etc/resolv.conf ${.TARGET}/etc/resolv.conf
 	echo sendmail_enable=\"NONE\" > ${.TARGET}/etc/rc.conf
diff --git a/release/arm/GENERICSD.conf b/release/arm/GENERICSD.conf
index 17086ba59185..98af1ef0d228 100644
--- a/release/arm/GENERICSD.conf
+++ b/release/arm/GENERICSD.conf
@@ -11,6 +11,10 @@ FAT_TYPE="16"
 IMAGE_SIZE="3072M"
 KERNEL="GENERIC"
 MD_ARGS="-x 63 -y 255"
-NODOC=1
+BBB_UBOOT_DIR="/usr/local/share/u-boot/u-boot-beaglebone"
+RPI_UBOOT_DIR="/usr/local/share/u-boot/u-boot-rpi2"
+RPI_FIRMWARE_DIR="/usr/local/share/rpi-firmware"
+RPI_OL_DIR="${RPI_FIRMWARE_DIR}/overlays"
+OVERLAYS="mmc.dtbo"
 PART_SCHEME="MBR"
 export BOARDNAME="GENERICSD"
diff --git a/release/arm/RPI-B.conf b/release/arm/RPI-B.conf
index 27fa6aac2644..f164edd25b90 100644
--- a/release/arm/RPI-B.conf
+++ b/release/arm/RPI-B.conf
@@ -12,7 +12,6 @@ FAT_TYPE="16"
 IMAGE_SIZE="3072M"
 KERNEL="RPI-B"
 MD_ARGS="-x 63 -y 255"
-NODOC=1
 UBOOT_DIR="/usr/local/share/u-boot/u-boot-rpi"
 RPI_FIRMWARE_DIR="/usr/local/share/rpi-firmware"
 OL_DIR="${RPI_FIRMWARE_DIR}/overlays"
diff --git a/release/arm64/PINE64-LTS.conf b/release/arm64/PINE64-LTS.conf
index 39fff59563f1..2605cfde486d 100644
--- a/release/arm64/PINE64-LTS.conf
+++ b/release/arm64/PINE64-LTS.conf
@@ -12,7 +12,6 @@ FAT_TYPE="16"
 IMAGE_SIZE="3072M"
 KERNEL="GENERIC"
 MD_ARGS="-x 63 -y 255"
-NODOC=1
 PART_SCHEME="MBR"
 FDT_OVERLAYS="sun50i-a64-timer,sun50i-a64-opp"
 export BOARDNAME="PINE64-LTS"
diff --git a/release/arm64/PINE64.conf b/release/arm64/PINE64.conf
index ed433f78caf6..377b8ffe96a6 100644
--- a/release/arm64/PINE64.conf
+++ b/release/arm64/PINE64.conf
@@ -12,7 +12,6 @@ FAT_TYPE="16"
 IMAGE_SIZE="3072M"
 KERNEL="GENERIC"
 MD_ARGS="-x 63 -y 255"
-NODOC=1
 PART_SCHEME="MBR"
 FDT_OVERLAYS="sun50i-a64-timer,sun50i-a64-opp"
 export BOARDNAME="PINE64"
diff --git a/release/arm64/PINEBOOK.conf b/release/arm64/PINEBOOK.conf
index cb09047b9c87..a4304a76b0ef 100644
--- a/release/arm64/PINEBOOK.conf
+++ b/release/arm64/PINEBOOK.conf
@@ -12,7 +12,6 @@ FAT_TYPE="16"
 IMAGE_SIZE="2560M"
 KERNEL="GENERIC"
 MD_ARGS="-x 63 -y 255"
-NODOC=1
 PART_SCHEME="MBR"
 FDT_OVERLAYS="sun50i-a64-timer,sun50i-a64-opp"
 export BOARDNAME="PINEBOOK"
diff --git a/release/arm64/ROCKPRO64.conf b/release/arm64/ROCKPRO64.conf
index 29d19bd8a46f..29946b2e3935 100644
--- a/release/arm64/ROCKPRO64.conf
+++ b/release/arm64/ROCKPRO64.conf
@@ -12,7 +12,6 @@ FAT_TYPE="16"
 IMAGE_SIZE="3072M"
 KERNEL="GENERIC"
 MD_ARGS="-x 63 -y 255"
-NODOC=1
 PART_SCHEME="GPT"
 export BOARDNAME="ROCKPRO64"
 
diff --git a/release/release.conf.sample b/release/release.conf.sample
index 7619670cecc8..8488be7587c7 100644
--- a/release/release.conf.sample
+++ b/release/release.conf.sample
@@ -17,8 +17,7 @@ SVNROOT="svn://svn.FreeBSD.org/"
 
 ## Set the src/, ports/, and doc/ branches or tags.
 SRCBRANCH="base/stable/12 at rHEAD"
-DOCBRANCH="doc/head at rHEAD"
-PORTBRANCH="ports/head at rHEAD"
+PORTBRANCH="main"
 
 ## Run svn co --force for src checkout.
 #SRC_FORCE_CHECKOUT=yes
@@ -29,6 +28,15 @@ PORTBRANCH="ports/head at rHEAD"
 #SRCBRANCH="https://github.com/freebsd/freebsd"
 #DOCBRANCH="https://github.com/freebsd/freebsd-doc"
 #PORTBRANCH="https://github.com/freebsd/freebsd-ports"
+## Do not explicitly require the devel/git port to be installed.
+#NOGIT=1
+## Set the version control system host.
+GITROOT="https://git.freebsd.org/"
+GITSRC="src.git"
+GITPORTS="ports.git"
+
+## Sample configuration for using git from ports.
+#GITCMD="/usr/local/bin/git clone -q --branch main"
 
 ## Set to override the default target architecture.
 #TARGET="amd64"
@@ -49,7 +57,6 @@ PORTBRANCH="ports/head at rHEAD"
 #KERNEL_FLAGS="-j $(( $(( $(sysctl -n hw.ncpu) + 1 )) / 2 ))"
 
 ## Set miscellaneous 'make release' settings.
-#NODOC=
 #NOPORTS=
 #NOSRC=
 #WITH_DVD=
@@ -84,10 +91,6 @@ PORTBRANCH="ports/head at rHEAD"
 ## the chroot.  This is intended for use when /usr/src already exists.
 #SRC_UPDATE_SKIP=
 
-## Set to a non-empty value skip checkout or update of /usr/doc in
-## the chroot.  This is intended for use when /usr/doc already exists.
-#DOC_UPDATE_SKIP=
-
 ## Set to a non-empty value skip checkout or update of /usr/ports in
 ## the chroot.  This is intended for use when /usr/ports already exists.
 #PORTS_UPDATE_SKIP=
diff --git a/release/release.sh b/release/release.sh
index c7ae9959e7dc..47c64e796404 100755
--- a/release/release.sh
+++ b/release/release.sh
@@ -70,9 +70,10 @@ env_setup() {
 	# The default svn checkout server, and svn branches for src/, doc/,
 	# and ports/.
 	SVNROOT="svn://svn.FreeBSD.org/"
-	SRCBRANCH="base/head at rHEAD"
-	DOCBRANCH="doc/head at rHEAD"
-	PORTBRANCH="ports/head at rHEAD"
+	SRCBRANCH="base/stable/12 at rHEAD"
+	PORTBRANCH="main"
+	GITROOT="https://git.FreeBSD.org/"
+	GITPORTS="ports.git"
 
 	# Set for embedded device builds.
 	EMBEDDEDBUILD=
@@ -98,8 +99,6 @@ env_setup() {
 	KERNEL="GENERIC"
 
 	# Set to non-empty value to disable checkout of doc/ and/or ports/.
-	# Disabling ports/ checkout also forces NODOC to be set.
-	NODOC=
 	NOPORTS=
 
 	# Set to non-empty value to disable distributing source tree.
@@ -140,13 +139,12 @@ env_check() {
 
 	# Prefix the branches with the SVNROOT for the full checkout URL.
 	SRCBRANCH="${SVNROOT}${SRCBRANCH}"
-	DOCBRANCH="${SVNROOT}${DOCBRANCH}"
-	PORTBRANCH="${SVNROOT}${PORTBRANCH}"
+	# Prefix the branches with the GITROOT for the full checkout URL.
+	PORT="${GITROOT}${GITPORTS}"
 
 	if [ -n "${EMBEDDEDBUILD}" ]; then
 		WITH_DVD=
 		WITH_COMPRESSED_IMAGES=
-		NODOC=yes
 		case ${EMBEDDED_TARGET}:${EMBEDDED_TARGET_ARCH} in
 			arm:arm*|arm64:aarch64)
 				chroot_build_release_cmd="chroot_arm_build_release"
@@ -156,26 +154,15 @@ env_check() {
 		esac
 	fi
 
-	# If PORTS is set and NODOC is unset, force NODOC=yes because the ports
-	# tree is required to build the documentation set.
-	if [ -n "${NOPORTS}" ] && [ -z "${NODOC}" ]; then
-		echo "*** NOTICE: Setting NODOC=1 since ports tree is required"
-		echo "            and NOPORTS is set."
-		NODOC=yes
-	fi
-
-	# If NOSRC, NOPORTS and/or NODOC are unset, they must not pass to make
+	# If NOSRC and/or NOPORTS are unset, they must not pass to make
 	# as variables.  The release makefile verifies definedness of the
-	# NOPORTS/NODOC variables instead of their values.
-	SRCDOCPORTS=
+	# NOPORTS variable instead of its value.
+	SRCPORTS=
 	if [ -n "${NOPORTS}" ]; then
-		SRCDOCPORTS="NOPORTS=yes"
-	fi
-	if [ -n "${NODOC}" ]; then
-		SRCDOCPORTS="${SRCDOCPORTS}${SRCDOCPORTS:+ }NODOC=yes"
+		SRCPORTS="NOPORTS=yes"
 	fi
 	if [ -n "${NOSRC}" ]; then
-		SRCDOCPORTS="${SRCDOCPORTS}${SRCDOCPORTS:+ }NOSRC=yes"
+		SRCPORTS="${SRCPORTS}${SRCPORTS:+ }NOSRC=yes"
 	fi
 
 	# The aggregated build-time flags based upon variables defined within
@@ -218,7 +205,7 @@ env_check() {
 	RELEASE_KMAKEFLAGS="${MAKE_FLAGS} ${KERNEL_FLAGS} \
 		KERNCONF=\"${KERNEL}\" ${ARCH_FLAGS} ${CONF_FILES}"
 	RELEASE_RMAKEFLAGS="${ARCH_FLAGS} \
-		KERNCONF=\"${KERNEL}\" ${CONF_FILES} ${SRCDOCPORTS} \
+		KERNCONF=\"${KERNEL}\" ${CONF_FILES} ${SRCPORTS} \
 		WITH_DVD=${WITH_DVD} WITH_VMIMAGES=${WITH_VMIMAGES} \
 		WITH_CLOUDWARE=${WITH_CLOUDWARE} XZ_THREADS=${XZ_THREADS}"
 
@@ -233,9 +220,6 @@ chroot_setup() {
 	if [ -z "${SRC_UPDATE_SKIP}" ]; then
 		${VCSCMD} ${FORCE_SRC_KEY} ${SRCBRANCH} ${CHROOTDIR}/usr/src
 	fi
-	if [ -z "${NODOC}" ] && [ -z "${DOC_UPDATE_SKIP}" ]; then
-		${VCSCMD} ${DOCBRANCH} ${CHROOTDIR}/usr/doc
-	fi
 	if [ -z "${NOPORTS}" ] && [ -z "${PORTS_UPDATE_SKIP}" ]; then
 		${VCSCMD} ${PORTBRANCH} ${CHROOTDIR}/usr/ports
 	fi
@@ -274,24 +258,37 @@ extra_chroot_setup() {
 		cp ${SRC_CONF} ${CHROOTDIR}/${SRC_CONF}
 	fi
 
-	if [ -d ${CHROOTDIR}/usr/ports ]; then
-		# Trick the ports 'run-autotools-fixup' target to do the right
-		# thing.
-		_OSVERSION=$(chroot ${CHROOTDIR} /usr/bin/uname -U)
-		REVISION=$(chroot ${CHROOTDIR} make -C /usr/src/release -V REVISION)
-		BRANCH=$(chroot ${CHROOTDIR} make -C /usr/src/release -V BRANCH)
-		UNAME_r=${REVISION}-${BRANCH}
-		if [ -d ${CHROOTDIR}/usr/doc ] && [ -z "${NODOC}" ]; then
+	if [ -z "${NOGIT}" ]; then
+		# Install git from ports or packages if the ports tree is
+		# available and VCSCMD is unset.
+		_gitcmd="$(which git)"
+		if [ -d ${CHROOTDIR}/usr/ports -a -z "${_gitcmd}" ]; then
+			# Trick the ports 'run-autotools-fixup' target to do the right
+			# thing.
+			_OSVERSION=$(chroot ${CHROOTDIR} /usr/bin/uname -U)
+			REVISION=$(chroot ${CHROOTDIR} make -C /usr/src/release -V REVISION)
+			BRANCH=$(chroot ${CHROOTDIR} make -C /usr/src/release -V BRANCH)
+			UNAME_r=${REVISION}-${BRANCH}
+			GITUNSETOPTS="CONTRIB CURL CVS GITWEB GUI HTMLDOCS"
+			GITUNSETOPTS="${GITUNSETOPTS} ICONV NLS P4 PERL"
+			GITUNSETOPTS="${GITUNSETOPTS} SEND_EMAIL SUBTREE SVN"
+			GITUNSETOPTS="${GITUNSETOPTS} PCRE PCRE2"
 			PBUILD_FLAGS="OSVERSION=${_OSVERSION} BATCH=yes"
 			PBUILD_FLAGS="${PBUILD_FLAGS} UNAME_r=${UNAME_r}"
 			PBUILD_FLAGS="${PBUILD_FLAGS} OSREL=${REVISION}"
 			PBUILD_FLAGS="${PBUILD_FLAGS} WRKDIRPREFIX=/tmp/ports"
 			PBUILD_FLAGS="${PBUILD_FLAGS} DISTDIR=/tmp/distfiles"
-			chroot ${CHROOTDIR} env ${PBUILD_FLAGS} \
-				OPTIONS_UNSET="AVAHI FOP IGOR" make -C \
-				/usr/ports/textproc/docproj \
-				FORCE_PKG_REGISTER=1 \
+			eval chroot ${CHROOTDIR} env OPTIONS_UNSET=\"${GITUNSETOPTS}\" \
+				${PBUILD_FLAGS} \
+				make -C /usr/ports/devel/git FORCE_PKG_REGISTER=1 \
+				WRKDIRPREFIX=/tmp/ports \
+				DISTDIR=/tmp/distfiles \
 				install clean distclean
+		else
+			eval chroot ${CHROOTDIR} env ASSUME_ALWAYS_YES=yes \
+				pkg install -y devel/git
+			eval chroot ${CHROOTDIR} env ASSUME_ALWAYS_YES=yes \
+				pkg clean -y
 		fi
 	fi
 


More information about the dev-commits-src-all mailing list